@@ -14,15 +14,26 @@
 
 
 """
-The Maven Project module handles creating Maven Jenkins projects.  To
-create a Maven project, specify ``maven`` in the ``project-type``
-attribute to the :ref:`Job` definition.
+The Maven Project module handles creating Maven Jenkins projects.
 
-It also requires a ``maven`` section in the :ref:`Job` definition.
-All of the fields below are required, except ``root-pom``, whose
-default is ``pom.xml``, and ``maven-name`` which will default to being
-unset. Not setting ``maven-name`` appears to use the first maven
-install defined in the global jenkins config.
+To create a Maven project, specify ``maven`` in the ``project-type``
+attribute to the :ref:`Job` definition. It also requires a ``maven`` section
+in the :ref:`Job` definition.
+
+:Job Parameters:
+    * **root-module**:
+        * **group-id** (`str`): GroupId. (required)
+        * **artifact-id** (`str`): ArtifactId. (required)
+    * **root-pom** (`str`): The path to the pom.xml file. (defaults to pom.xml)
+    * **goals** (`str`): Goals to execute. (required)
+    * **maven-opts** (`str`): Java options to pass to maven (aka MAVEN_OPTS)
+    * **maven-name** (`str`): Installation of maven which should be used.
+      Not setting ``maven-name`` appears to use the first maven install
+      defined in the global jenkins config.
+    * **ignore-upstream-changes** (`bool`): Do not start a build whenever
+      a SNAPSHOT dependency is built or not. (defaults to true)
+    * **automatic-archiving** (`bool`): Activate automatic artifact archiving
+      (defaults to true).
 
 Example::
 
@@ -36,7 +47,9 @@ Example::
         artifact-id: example-guide
       root-pom: doc/src/pom.xml
       goals: "clean generate-sources"
+      maven-opts: '-Dmyvar=/path/somewhere'
       maven-name: Maven3
+      automatic-archiving: true
 """
 
 import xml.etree.ElementTree as XML
@@ -50,24 +63,31 @@ class Maven(jenkins_jobs.modules.base.Base):
         if 'maven' not in data:
             return None
         xml_parent = XML.Element('maven2-moduleset')
-        root_module = XML.SubElement(xml_parent, 'root_module')
+        root_module = XML.SubElement(xml_parent, 'rootModule')
         XML.SubElement(root_module, 'groupId').text = \
             data['maven']['root-module']['group-id']
         XML.SubElement(root_module, 'artifactId').text = \
             data['maven']['root-module']['artifact-id']
         XML.SubElement(xml_parent, 'goals').text = data['maven']['goals']
 
+        maven_opts = data['maven'].get('maven-opts')
+        if maven_opts:
+            XML.SubElement(xml_parent, 'mavenOpts').text = maven_opts
+
         maven_name = data['maven'].get('maven-name')
         if maven_name:
             XML.SubElement(xml_parent, 'mavenName').text = maven_name
 
+        XML.SubElement(xml_parent, 'ignoreUpstremChanges').text = str(
+            data['maven'].get('ignore-upstream-changes', 'true')).lower()
+
         XML.SubElement(xml_parent, 'rootPOM').text = \
             data['maven'].get('root-pom', 'pom.xml')
         XML.SubElement(xml_parent, 'aggregatorStyleBuild').text = 'true'
         XML.SubElement(xml_parent, 'incrementalBuild').text = 'false'
         XML.SubElement(xml_parent, 'perModuleEmail').text = 'true'
-        XML.SubElement(xml_parent, 'ignoreUpstremChanges').text = 'true'
-        XML.SubElement(xml_parent, 'archivingDisabled').text = 'false'
+        XML.SubElement(xml_parent, 'archivingDisabled').text = str(
+            not data['maven'].get('automatic-archiving', True)).lower()
         XML.SubElement(xml_parent, 'resolveDependencies').text = 'false'
         XML.SubElement(xml_parent, 'processPlugins').text = 'false'
         XML.SubElement(xml_parent, 'mavenValidationLevel').text = '-1'
